/* eslint-disable no-undef */
import React from 'react';
import { Link, Route, Switch } from 'dva/router';
import { Affix } from 'antd';
import ReactMarkdown from 'react-markdown';
import 'github-markdown-css';
import styles from './index.less';
import mdIndex from './index.md';
import mdAuth from './auth.md';
import mdDomain from './domain.md';
import mdDyInt from './dynamic-interface/index.md';
import mdDyAddFamily from './dynamic-interface/addFamily.md';
import mdDyUpdateFamily from './dynamic-interface/updateFamily.md';
import mdDyRemoveFamily from './dynamic-interface/removeFamily.md';

const md = mdString => props => (
  <div style={{
    padding: '1em',
    background: '#fafafa',
  }}
  >
    <ReactMarkdown {...props} className="markdown-body" source={mdString} />
  </div>
);

class DocMainPage extends React.Component {
  render() {
    const { match } = this.props;
    return (
      <div className={styles.main} ref={(node) => { this.container = node && node.parentElement; }}>
        <Affix target={() => this.container}>
          <ul className={styles.catalogue}>
            <li>
              <Link to={`${match.url}/index`}>前置说明</Link>
            </li>
            <li>
              <Link to={`${match.url}/auth`}>登录与认证</Link>
            </li>
            <li>
              <Link to={`${match.url}/domain`}>作用域</Link>
            </li>
            <li>
              <Link to={`${match.url}/dynamic-interface`}>动态接口</Link>
              <ul>
                <li><Link to={`${match.url}/dynamic-interface/addFamily`}>新增两清</Link></li>
                <li><Link to={`${match.url}/dynamic-interface/updateFamily`}>更新两清</Link></li>
                <li><Link to={`${match.url}/dynamic-interface/removeFamily`}>删除两清</Link></li>
              </ul>
            </li>
          </ul>
        </Affix>
        <div className={styles.contents}>
          <Switch>
            <Route path={`${match.path}/index`} component={md(mdIndex)} />
            <Route path={`${match.path}/auth`} component={md(mdAuth)} />
            <Route path={`${match.path}/domain`} component={md(mdDomain)} />
            <Route path={`${match.path}/dynamic-interface`} exact component={md(mdDyInt)} />
            <Route path={`${match.path}/dynamic-interface/addFamily`} component={md(mdDyAddFamily)} />
            <Route path={`${match.path}/dynamic-interface/updateFamily`} component={md(mdDyUpdateFamily)} />
            <Route path={`${match.path}/dynamic-interface/removeFamily`} component={md(mdDyRemoveFamily)} />
            <Route path={`${match.path}/dynamic-interface/addHouse`} component={md(mdDyAddFamily)} />
            <Route path={`${match.path}/dynamic-interface/updateHouse`} component={md(mdDyAddFamily)} />
            <Route path={`${match.path}/dynamic-interface/removeHouse`} component={md(mdDyAddFamily)} />
            <Route path={`${match.path}/dynamic-interface/addPeople`} component={md(mdDyAddFamily)} />
            <Route path={`${match.path}/dynamic-interface/updatePeople`} component={md(mdDyAddFamily)} />
            <Route path={`${match.path}/dynamic-interface/removePeople`} component={md(mdDyAddFamily)} />
          </Switch>
        </div>
      </div>
    );
  }
}

export default DocMainPage;
